@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 1;
 
@@ -59,7 +59,7 @@ L<Map::Tube::Yekaterinburg>.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Taks-Map-Tube>
+L<https://github.com/tupinek/Task-Map-Tube>
 
 =head1 AUTHOR
 
@@ -75,6 +75,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
